@@ -222,15 +222,11 @@ class Stacktrace(Interface):
         })
 
     def to_string(self, event):
-        r = ['Stacktrace (most recent call last):']
-        for f in self.frames:
-            r.append('  File "%(filename)s", line %(lineno)s, in %(function)s\n    %(context_line)s' % f)
-        return '\n'.join(r)
+        return self.get_stacktrace(event)
 
-    def get_traceback(self, event):
+    def get_stacktrace(self, event):
         result = [
-            event.message, '',
-            'Traceback (most recent call last):', '',
+            'Stacktrace (most recent call last):', '',
         ]
         for frame in self.frames:
             if 'function' in frame:
@@ -243,6 +239,14 @@ class Stacktrace(Interface):
 
         return '\n'.join(result)
 
+    def get_traceback(self, event):
+        result = [
+            event.message, '',
+            self.get_stacktrace(event),
+        ]
+
+        return '\n'.join(result)
+
     def get_search_context(self, event):
         return {
             'text': list(itertools.chain(*[[f.get('filename'), f.get('function'), f.get('context_line')] for f in self.frames])),
@@ -338,6 +342,15 @@ class Http(Interface):
             'env': self.env,
         }
 
+    def to_string(self, event):
+        return render_to_string('sentry/partial/interfaces/http.txt', {
+            'event': event,
+            'full_url': '?'.join(filter(None, [self.url, self.query_string])),
+            'url': self.url,
+            'method': self.method,
+            'query_string': self.query_string,
+        })
+
     def to_html(self, event):
         data = self.data
         data_is_dict = False
@@ -407,6 +420,14 @@ class Template(Interface):
     def get_hash(self):
         return [self.filename, self.context_line]
 
+    def to_string(self, event):
+        result = [
+            'Stacktrace (most recent call last):', '',
+            self.get_traceback()
+        ]
+
+        return '\n'.join(result)
+
     def to_html(self, event):
         context = get_context(self.lineno, self.context_line, self.pre_context, self.post_context)
 
